@@ -13,20 +13,6 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
-
-    Change History (most recent first):
-
-$Log: Searcher.c,v $
-Revision 1.3  2006/08/14 23:24:29  cheshire
-Re-licensed mDNSResponder daemon source code under Apache License, Version 2.0
-
-Revision 1.2  2004/05/27 06:30:21  cheshire
-Add code to test DNSServiceQueryRecord()
-
-Revision 1.1  2004/03/12 21:30:25  cheshire
-Build a System-Context Shared Library from mDNSCore, for the benefit of developers
-like Muse Research who want to be able to use mDNS/DNS-SD from GPL-licensed code.
-
  */
 
 #include <stdio.h>						// For printf()
@@ -132,7 +118,7 @@ static void FoundInstanceAddress(DNSServiceRef sdRef, DNSServiceFlags flags, uin
 
 static void FoundInstanceInfo(DNSServiceRef sdRef, DNSServiceFlags flags, uint32_t interfaceIndex,
 	DNSServiceErrorType errorCode, const char *fullname, const char *hosttarget, uint16_t notAnIntPort,
-	uint16_t txtLen, const char *txtRecord, void *context)
+	uint16_t txtLen, const unsigned char *txtRecord, void *context)
 	{
 	linkedServiceInfo *info = (linkedServiceInfo *)context;
 	SearcherServices *services = info->services;
@@ -145,7 +131,7 @@ static void FoundInstanceInfo(DNSServiceRef sdRef, DNSServiceFlags flags, uint32
 	if (txtLen == 0) info->text[0] = 0;
 	else
 		{
-		strncpy(info->text, txtRecord+1, txtRecord[0]);
+		strncpy(info->text, (char *)txtRecord+1, txtRecord[0]);
 		info->text[txtRecord[0]] = 0;
 		}
 	info->notAnIntPort.NotAnInteger = notAnIntPort;
