@@ -13,19 +13,6 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
-
-    Change History (most recent first):
-
-$Log: DNSServiceDiscoveryDefines.h,v $
-Revision 1.7  2006/08/14 23:24:39  cheshire
-Re-licensed mDNSResponder daemon source code under Apache License, Version 2.0
-
-Revision 1.6  2004/09/20 21:45:27  ksekar
-Mach IPC cleanup
-
-Revision 1.5  2003/08/12 19:56:25  cheshire
-Update to APSL 2.0
-
  */
 
 #ifndef __DNS_SERVICE_DISCOVERY_DEFINES_H
@@ -33,7 +20,7 @@ Update to APSL 2.0
 
 #include <mach/mach_types.h>
 
-#define DNS_SERVICE_DISCOVERY_SERVER "DNSServiceDiscoveryServer"
+#define DNS_SERVICE_DISCOVERY_SERVER "com.apple.mDNSResponder"
 
 typedef char    DNSCString[1024];
 typedef char    sockaddr_t[128];
