@@ -3,7 +3,7 @@
 
     Abstract: System Preference Pane for Dynamic DNS and Wide-Area DNS Service Discovery
 
-    Copyright: (c) Copyright 2005 Apple Computer, Inc. All rights reserved.
+    Copyright: (c) Copyright 2005-2011 Apple Computer, Inc. All rights reserved.
 
     Disclaimer: IMPORTANT: This Apple software is supplied to you by Apple Computer, Inc.
     ("Apple") in consideration of your agreement to the following terms, and your
@@ -340,13 +340,13 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 }
 
 
-- (void)tableViewSelectionDidChange:(NSNotification *)notification;
+- (void)tableViewSelectionDidChange:(NSNotification *)notification
 {
 	[removeBrowseDomainButton setEnabled:[[notification object] numberOfSelectedRows]];
 }
 
 
-- (void)setBrowseDomainsComboBox;
+- (void)setBrowseDomainsComboBox
 {
 	NSString * domain = nil;
 	
@@ -361,7 +361,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 }
 
 
-- (IBAction)addBrowseDomainClicked:(id)sender;
+- (IBAction)addBrowseDomainClicked:(id)sender
 {
 	[self setBrowseDomainsComboBox];
 
@@ -373,7 +373,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 }
 
 
-- (IBAction)removeBrowseDomainClicked:(id)sender;
+- (IBAction)removeBrowseDomainClicked:(id)sender
 {
 	(void)sender; // Unused
 	int selectedBrowseDomain = [browseDomainList selectedRow];
@@ -383,7 +383,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 }
 
 
-- (IBAction)enableBrowseDomainClicked:(id)sender;
+- (IBAction)enableBrowseDomainClicked:(id)sender
 {
 	NSTableView *tableView = sender;
     NSMutableDictionary *browseDomainDict;
@@ -399,7 +399,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 
 
 
-- (NSInteger)numberOfRowsInTableView:(NSTableView *)tableView;
+- (NSInteger)numberOfRowsInTableView:(NSTableView *)tableView
 {
 	(void)tableView; // Unused
 	int numberOfRows = 0;
@@ -411,7 +411,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 }
 
 
-- (void)tabView:(NSTabView *)xtabView didSelectTabViewItem:(NSTabViewItem *)tabViewItem;
+- (void)tabView:(NSTabView *)xtabView didSelectTabViewItem:(NSTabViewItem *)tabViewItem
 {
 	(void)xtabView; // Unused
 	(void)tabViewItem; // Unused
@@ -420,7 +420,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 }
  
 
-- (id)tableView:(NSTableView *)tableView objectValueForTableColumn:(NSTableColumn *)tableColumn row:(NSInteger)row;
+- (id)tableView:(NSTableView *)tableView objectValueForTableColumn:(NSTableColumn *)tableColumn row:(NSInteger)row
 {
 	(void)tableView; // Unused
 	NSDictionary *browseDomainDict;
@@ -460,7 +460,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 			[browseDomainsArray sortUsingFunction:MyDomainArrayCompareFunction context:nil];
 			if ([browseDomainsArray isEqualToArray:currentBrowseDomainsArray] == NO) {
 				OSStatus err = WriteBrowseDomain((CFDataRef)[self dataForDomainArray:browseDomainsArray]);
-				if (err != noErr) NSLog(@"WriteBrowseDomain returned %d\n", err);
+				if (err != noErr) NSLog(@"WriteBrowseDomain returned %d\n", (int32_t)err);
 				[currentBrowseDomainsArray release];
 				currentBrowseDomainsArray = [browseDomainsArray copy];
 			}
@@ -703,7 +703,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 
 
 
-- (void)controlTextDidChange:(NSNotification *)notification;
+- (void)controlTextDidChange:(NSNotification *)notification
 {
 	(void)notification; // Unused
     [self updateApplyButtonState];
@@ -711,7 +711,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 
 
 
-- (IBAction)comboAction:(id)sender;
+- (IBAction)comboAction:(id)sender
 {
 	(void)sender; // Unused
     [self updateApplyButtonState];
@@ -859,7 +859,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 }
 
 
-- (IBAction)revertClicked:(id)sender;
+- (IBAction)revertClicked:(id)sender
 {
     [self restorePreferences];
 	[browseDomainList deselectAll:sender];
@@ -1042,7 +1042,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
     // Save hostname.
     if ((currentHostName == NULL) || [currentHostName compare:hostNameString] != NSOrderedSame) {
 		err = WriteHostname((CFDataRef)[self dataForDomain:hostNameString isEnabled:YES]);
-		if (err != noErr) NSLog(@"WriteHostname returned %d\n", err);
+		if (err != noErr) NSLog(@"WriteHostname returned %d\n", (int32_t)err);
         currentHostName = [hostNameString copy];
     } else if (hostSecretWasSet) {
 		WriteHostname((CFDataRef)[self dataForDomain:@"" isEnabled:NO]);
@@ -1054,7 +1054,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 	if (browseDomainsArray && [browseDomainsArray isEqualToArray:currentBrowseDomainsArray] == NO) {
 		browseDomainData = [self dataForDomainArray:browseDomainsArray];
 		err = WriteBrowseDomain((CFDataRef)browseDomainData);
-		if (err != noErr) NSLog(@"WriteBrowseDomain returned %d\n", err);
+		if (err != noErr) NSLog(@"WriteBrowseDomain returned %d\n", (int32_t)err);
 		currentBrowseDomainsArray = [browseDomainsArray copy];
     }
 	
@@ -1062,7 +1062,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
     if ((currentRegDomain == NULL) || ([currentRegDomain compare:regDomainString] != NSOrderedSame) || (currentWideAreaState != [wideAreaCheckBox state])) {
 
 		err = WriteRegistrationDomain((CFDataRef)[self dataForDomain:regDomainString isEnabled:[wideAreaCheckBox state]]);
-		if (err != noErr) NSLog(@"WriteRegistrationDomain returned %d\n", err);
+		if (err != noErr) NSLog(@"WriteRegistrationDomain returned %d\n", (int32_t)err);
         
 		if (currentRegDomain) CFRelease(currentRegDomain);
         currentRegDomain = [regDomainString copy];
@@ -1133,7 +1133,7 @@ MyDNSServiceAddServiceToRunLoop(MyDNSServiceState * query)
 }
 
 
-- (BOOL)tableView:(NSTableView *)tableView shouldSelectRow:(NSInteger)row;
+- (BOOL)tableView:(NSTableView *)tableView shouldSelectRow:(NSInteger)row
 {
 	(void)row; // Unused
 	(void)tableView; // Unused
