@@ -52,8 +52,11 @@
 #	include <mDNSEmbeddedAPI.h>
 #	include <mDNSWin32.h>
 #	include <PosixCompat.h>
+#	include <Poll.h>
 #	define IFNAMSIZ 256
 static HANDLE gStopEvent = INVALID_HANDLE_VALUE;
+static mDNSBool gRunning;
+static void CALLBACK StopNotification( HANDLE event, void *context ) { gRunning = mDNSfalse; }
 static BOOL WINAPI ConsoleControlHandler( DWORD inControlEvent ) { SetEvent( gStopEvent ); return TRUE; }
 void setlinebuf( FILE * fp ) {}
 #else
@@ -478,7 +481,7 @@ mDNSlocal void DisplayPacketHeader(mDNS *const m, const DNSMessage *const msg, c
 
 	struct timeval tv;
 	struct tm tm;
-	const mDNSu32 index = mDNSPlatformInterfaceIndexfromInterfaceID(m, InterfaceID);
+	const mDNSu32 index = mDNSPlatformInterfaceIndexfromInterfaceID(m, InterfaceID, mDNSfalse);
 	char if_name[IFNAMSIZ];		// Older Linux distributions don't define IF_NAMESIZE
 	if_indextoname(index, if_name);
 	gettimeofday(&tv, NULL);
@@ -795,7 +798,7 @@ mDNSexport void mDNSCoreReceive(mDNS *const m, DNSMessage *const msg, const mDNS
 
 	// For now we're only interested in monitoring IPv4 traffic.
 	// All IPv6 packets should just be duplicates of the v4 packets.
-	if (!goodinterface) goodinterface = (FilterInterface == (int)mDNSPlatformInterfaceIndexfromInterfaceID(m, InterfaceID));
+	if (!goodinterface) goodinterface = (FilterInterface == (int)mDNSPlatformInterfaceIndexfromInterfaceID(m, InterfaceID, mDNSfalse));
 	if (goodinterface && AddressMatchesFilterList(srcaddr))
 		{
 		mDNS_Lock(m);
@@ -840,10 +843,9 @@ mDNSlocal mStatus mDNSNetMonitor(void)
 	if (status) return(status);
 	gStopEvent = CreateEvent(NULL, FALSE, FALSE, NULL);
 	if (gStopEvent == INVALID_HANDLE_VALUE) return mStatus_UnknownErr;
+	mDNSPollRegisterEvent( gStopEvent, StopNotification, NULL );
 	if (!SetConsoleCtrlHandler(ConsoleControlHandler, TRUE)) return mStatus_UnknownErr;
-	SetSocketEventsEnabled(&mDNSStorage, TRUE);
-	while (WaitForSingleObjectEx(gStopEvent, INFINITE, TRUE) == WAIT_IO_COMPLETION);
-	SetSocketEventsEnabled(&mDNSStorage, FALSE);
+	gRunning = mDNStrue; while (gRunning) mDNSPoll( INFINITE );
 	if (!SetConsoleCtrlHandler(ConsoleControlHandler, FALSE)) return mStatus_UnknownErr;
 	CloseHandle(gStopEvent);
 #else
