@@ -29,8 +29,14 @@
 #include <errno.h>
 #include <stdlib.h>
 
+#if APPLE_OSX_mDNSResponder
+#include <mach-o/dyld.h>
+#endif
+
 #include "dnssd_ipc.h"
 
+static int gDaemonErr = kDNSServiceErr_NoError;
+
 #if defined(_WIN32)
 
 	#define _SSIZE_T
@@ -40,6 +46,7 @@
 	#include <ws2tcpip.h>
 	#include <windows.h>
 	#include <stdarg.h>
+	#include <stdio.h>
 	
 	#define sockaddr_mdns sockaddr_in
 	#define AF_MDNS AF_INET
@@ -56,6 +63,7 @@
 	
 	static int g_initWinsock = 0;
 	#define LOG_WARNING kDebugLevelWarning
+	#define LOG_INFO kDebugLevelInfo
 	static void syslog( int priority, const char * message, ...)
 		{
 		va_list args;
@@ -88,6 +96,8 @@
 // Uncomment the line below to use the old error return mechanism of creating a temporary named socket (e.g. in /var/tmp)
 //#define USE_NAMED_ERROR_RETURN_SOCKET 1
 
+#define DNSSD_CLIENT_TIMEOUT 10  // In seconds
+
 #ifndef CTL_PATH_PREFIX
 #define CTL_PATH_PREFIX "/var/tmp/dnssd_result_socket."
 #endif
@@ -196,6 +206,9 @@ static int read_all(dnssd_sock_t sd, char *buf, int len)
 	while (len)
 		{
 		ssize_t num_read = recv(sd, buf, len, 0);
+		// It is valid to get an interrupted system call error e.g., somebody attaching
+		// in a debugger, retry without failing
+		if ((num_read < 0) && (errno == EINTR)) { syslog(LOG_INFO, "dnssd_clientstub read_all: EINTR continue"); continue; }
 		if ((num_read == 0) || (num_read < 0) || (num_read > len))
 			{
 			int printWarn = 0;
@@ -262,6 +275,39 @@ static int more_bytes(dnssd_sock_t sd)
 	return (ret > 0);
 	}
 
+// Wait for daemon to write to socket
+static int wait_for_daemon(dnssd_sock_t sock, int timeout)
+	{
+#ifndef WIN32
+	// At this point the next operation (accept() or read()) on this socket may block for a few milliseconds waiting
+	// for the daemon to respond, but that's okay -- the daemon is a trusted service and we know if won't take more
+	// than a few milliseconds to respond.  So we'll forego checking for readability of the socket.
+	(void) sock;
+	(void) timeout;
+#else
+	// Windows on the other hand suffers from 3rd party software (primarily 3rd party firewall software) that
+	// interferes with proper functioning of the TCP protocol stack. Because of this and because we depend on TCP
+	// to communicate with the system service, we want to make sure that the next operation on this socket (accept() or
+	// read()) doesn't block indefinitely.
+	if (!gDaemonErr)
+		{
+		struct timeval tv;
+		fd_set set;
+
+		FD_ZERO(&set);
+		FD_SET(sock, &set);
+		tv.tv_sec = timeout;
+		tv.tv_usec = 0;
+		if (!select((int)(sock + 1), &set, NULL, NULL, &tv))
+			{
+				syslog(LOG_WARNING, "dnssd_clientstub wait_for_daemon timed out");
+				gDaemonErr = kDNSServiceErr_Timeout;
+			}
+		}
+#endif
+	return gDaemonErr;
+	}
+
 /* create_hdr
  *
  * allocate and initialize an ipc message header. Value of len should initially be the
@@ -353,7 +399,6 @@ static void FreeDNSServiceOp(DNSServiceOp *x)
 		x->ProcessReply = NULL;
 		x->AppCallback  = NULL;
 		x->AppContext   = NULL;
-		x->rec          = NULL;
 #if _DNS_SD_LIBDISPATCH
 		if (x->disp_source)	dispatch_release(x->disp_source);
 		x->disp_source  = NULL;
@@ -612,7 +657,10 @@ static DNSServiceErrorType deliver_request(ipc_msg_hdr *hdr, DNSServiceOp *sdr)
 #else
 	if (write_all(sdr->sockfd, (char *)hdr, datalen + sizeof(ipc_msg_hdr)) < 0)
 		{
-		syslog(LOG_WARNING, "dnssd_clientstub deliver_request ERROR: write_all(%d, %lu bytes) failed",
+		// write_all already prints an error message if there is an error writing to
+		// the socket except for DEFUNCT. Logging here is unnecessary and also wrong
+		// in the case of DEFUNCT sockets
+		syslog(LOG_INFO, "dnssd_clientstub deliver_request ERROR: write_all(%d, %lu bytes) failed",
 			sdr->sockfd, (unsigned long)(datalen + sizeof(ipc_msg_hdr)));
 		goto cleanup;
 		}
@@ -626,6 +674,7 @@ static DNSServiceErrorType deliver_request(ipc_msg_hdr *hdr, DNSServiceOp *sdr)
 		// but that's okay -- the daemon is a trusted service and we know if won't take more than a few milliseconds to respond.
 		dnssd_sockaddr_t daddr;
 		dnssd_socklen_t len = sizeof(daddr);
+		if ((err = wait_for_daemon(listenfd, DNSSD_CLIENT_TIMEOUT)) != kDNSServiceErr_NoError) goto cleanup;
 		errsd = accept(listenfd, (struct sockaddr *)&daddr, &len);
 		if (!dnssd_SocketValid(errsd)) deliver_request_bailout("accept");
 #else
@@ -711,10 +760,13 @@ static DNSServiceErrorType deliver_request(ipc_msg_hdr *hdr, DNSServiceOp *sdr)
 	// but that's okay -- the daemon is a trusted service and we know if won't take more than a few milliseconds to respond.
 	if (sdr->op == send_bpf)	// Okay to use sdr->op when checking for op == send_bpf
 		err = kDNSServiceErr_NoError;
-	else if (read_all(errsd, (char*)&err, (int)sizeof(err)) < 0)
-		err = kDNSServiceErr_ServiceNotRunning;	// On failure read_all will have written a message to syslog for us
-	else
-		err = ntohl(err);
+	else if ((err = wait_for_daemon(errsd, DNSSD_CLIENT_TIMEOUT)) == kDNSServiceErr_NoError)
+		{
+		if (read_all(errsd, (char*)&err, (int)sizeof(err)) < 0)
+			err = kDNSServiceErr_ServiceNotRunning; // On failure read_all will have written a message to syslog for us
+		else
+			err = ntohl(err);
+		}
 
 	//syslog(LOG_WARNING, "dnssd_clientstub deliver_request: retrieved error code %d", err);
 
@@ -1075,6 +1127,34 @@ fail:
 	syslog(LOG_WARNING, "dnssd_clientstub handle_resolve_response: error reading result from daemon");
 	}
 
+#if APPLE_OSX_mDNSResponder
+
+static int32_t	libSystemVersion = 0;
+
+// Return true if the application linked against a version of libsystem where P2P
+// interfaces were included by default when using kDNSServiceInterfaceIndexAny.
+// Using 160.0.0 == 0xa00000 as the version threshold.
+static int includeP2PWithIndexAny()
+	{
+	if (libSystemVersion == 0) 
+		libSystemVersion = NSVersionOfLinkTimeLibrary("System");
+
+	if (libSystemVersion < 0xa00000)
+		return 1;
+	else
+		return 0;
+	}
+
+#else	// APPLE_OSX_mDNSResponder
+
+// always return false for non Apple platforms
+static int includeP2PWithIndexAny()
+	{
+	return 0;
+	}
+
+#endif	// APPLE_OSX_mDNSResponder
+
 DNSServiceErrorType DNSSD_API DNSServiceResolve
 	(
 	DNSServiceRef                 *sdRef,
@@ -1094,6 +1174,19 @@ DNSServiceErrorType DNSSD_API DNSServiceResolve
 
 	if (!name || !regtype || !domain || !callBack) return kDNSServiceErr_BadParam;
 
+	// Need a real InterfaceID for WakeOnResolve
+	if ((flags & kDNSServiceFlagsWakeOnResolve) != 0 &&
+		((interfaceIndex == kDNSServiceInterfaceIndexAny) ||
+		(interfaceIndex == kDNSServiceInterfaceIndexLocalOnly) ||
+		(interfaceIndex == kDNSServiceInterfaceIndexUnicast) ||
+		(interfaceIndex == kDNSServiceInterfaceIndexP2P)))
+		{
+		return kDNSServiceErr_BadParam;
+		}
+		
+	if ((interfaceIndex == kDNSServiceInterfaceIndexAny) && includeP2PWithIndexAny())
+		flags |= kDNSServiceFlagsIncludeP2P;
+
 	err = ConnectToServer(sdRef, flags, resolve_request, handle_resolve_response, callBack, context);
 	if (err) return err;	// On error ConnectToServer leaves *sdRef set to NULL
 
@@ -1152,7 +1245,12 @@ DNSServiceErrorType DNSSD_API DNSServiceQueryRecord
 	char *ptr;
 	size_t len;
 	ipc_msg_hdr *hdr;
-	DNSServiceErrorType err = ConnectToServer(sdRef, flags, query_request, handle_query_response, callBack, context);
+	DNSServiceErrorType err;
+
+	if ((interfaceIndex == kDNSServiceInterfaceIndexAny) && includeP2PWithIndexAny())
+		flags |= kDNSServiceFlagsIncludeP2P;
+
+	err = ConnectToServer(sdRef, flags, query_request, handle_query_response, callBack, context);
 	if (err) return err;	// On error ConnectToServer leaves *sdRef set to NULL
 
 	if (!name) name = "\0";
@@ -1297,7 +1395,12 @@ DNSServiceErrorType DNSSD_API DNSServiceBrowse
 	char *ptr;
 	size_t len;
 	ipc_msg_hdr *hdr;
-	DNSServiceErrorType err = ConnectToServer(sdRef, flags, browse_request, handle_browse_response, callBack, context);
+	DNSServiceErrorType err;
+
+	if ((interfaceIndex == kDNSServiceInterfaceIndexAny) && includeP2PWithIndexAny())
+		flags |= kDNSServiceFlagsIncludeP2P;
+
+	err = ConnectToServer(sdRef, flags, browse_request, handle_browse_response, callBack, context);
 	if (err) return err;	// On error ConnectToServer leaves *sdRef set to NULL
 
 	if (!domain) domain = "";
@@ -1381,6 +1484,9 @@ DNSServiceErrorType DNSSD_API DNSServiceRegister
 	// No callback must have auto-rename
 	if (!callBack && (flags & kDNSServiceFlagsNoAutoRename)) return kDNSServiceErr_BadParam;
 
+	if ((interfaceIndex == kDNSServiceInterfaceIndexAny) && includeP2PWithIndexAny())
+		flags |= kDNSServiceFlagsIncludeP2P;
+
 	err = ConnectToServer(sdRef, flags, reg_service_request, callBack ? handle_regservice_response : NULL, callBack, context);
 	if (err) return err;	// On error ConnectToServer leaves *sdRef set to NULL
 
@@ -1526,6 +1632,9 @@ DNSServiceErrorType DNSSD_API DNSServiceRegisterRecord
 	int f2 = (flags & kDNSServiceFlagsUnique) != 0;
 	if (f1 + f2 != 1) return kDNSServiceErr_BadParam;
 
+	if ((interfaceIndex == kDNSServiceInterfaceIndexAny) && includeP2PWithIndexAny())
+		flags |= kDNSServiceFlagsIncludeP2P;
+
 	if (!sdRef) { syslog(LOG_WARNING, "dnssd_clientstub DNSServiceRegisterRecord called with NULL DNSServiceRef"); return kDNSServiceErr_BadParam; }
 
 	if (!DNSServiceRefValid(sdRef))
