@@ -1,125 +1,23 @@
-/*
+/* -*- Mode: C; tab-width: 4 -*-
+ *
  * Copyright (c) 2002-2003 Apple Computer, Inc. All rights reserved.
  *
- * @APPLE_LICENSE_HEADER_START@
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
- * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
- * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
  * limitations under the License.
- * 
- * @APPLE_LICENSE_HEADER_END@
 
 	Contains:	mDNS platform plugin for VxWorks.
 
 	Copyright:  Copyright (C) 2002-2004 Apple Computer, Inc., All Rights Reserved.
 
-	Change History (most recent first):
-
-$Log: mDNSVxWorksIPv4Only.c,v $
-Revision 1.27  2004/12/17 23:37:49  cheshire
-<rdar://problem/3485365> Guard against repeating wireless dissociation/re-association
-(and other repetitive configuration changes)
-
-Revision 1.26  2004/10/28 02:00:35  cheshire
-<rdar://problem/3841770> Call pipeDevDelete when disposing of commandPipe
-
-Revision 1.25  2004/10/16 00:17:01  cheshire
-<rdar://problem/3770558> Replace IP TTL 255 check with local subnet source address check
-
-Revision 1.24  2004/09/21 21:02:56  cheshire
-Set up ifname before calling mDNS_RegisterInterface()
-
-Revision 1.23  2004/09/17 01:08:57  cheshire
-Renamed mDNSClientAPI.h to mDNSEmbeddedAPI.h
-  The name "mDNSClientAPI.h" is misleading to new developers looking at this code. The interfaces
-  declared in that file are ONLY appropriate to single-address-space embedded applications.
-  For clients on general-purpose computers, the interfaces defined in dns_sd.h should be used.
-
-Revision 1.22  2004/09/17 00:19:11  cheshire
-For consistency with AllDNSLinkGroupv6, rename AllDNSLinkGroup to AllDNSLinkGroupv4
-
-Revision 1.21  2004/09/16 00:24:50  cheshire
-<rdar://problem/3803162> Fix unsafe use of mDNSPlatformTimeNow()
-
-Revision 1.20  2004/09/14 23:42:36  cheshire
-<rdar://problem/3801296> Need to seed random number generator from platform-layer data
-
-Revision 1.19  2004/09/14 23:16:09  cheshire
-mDNS_SetFQDNs has been renamed to mDNS_SetFQDN
-
-Revision 1.18  2004/08/14 03:22:42  cheshire
-<rdar://problem/3762579> Dynamic DNS UI <-> mDNSResponder glue
-Add GetUserSpecifiedDDNSName() routine
-Convert ServiceRegDomain to domainname instead of C string
-Replace mDNS_GenerateFQDN/mDNS_GenerateGlobalFQDN with mDNS_SetFQDNs
-
-Revision 1.17  2004/07/29 19:26:03  ksekar
-Plaform-level changes for NATPMP support
-
-Revision 1.16  2004/04/22 05:11:28  bradley
-Added mDNSPlatformUTC for TSIG signed dynamic updates.
-
-Revision 1.15  2004/04/21 02:49:12  cheshire
-To reduce future confusion, renamed 'TxAndRx' to 'McastTxRx'
-
-Revision 1.14  2004/04/09 17:43:04  cheshire
-Make sure to set the McastTxRx field so that duplicate suppression works correctly
-
-Revision 1.13  2004/01/27 20:15:24  cheshire
-<rdar://problem/3541288>: Time to prune obsolete code for listening on port 53
-
-Revision 1.12  2004/01/24 09:12:37  bradley
-Avoid TOS socket options to workaround a TOS routing problem with VxWorks and multiple interfaces
-when sending unicast responses, which resulted in packets going out the wrong interface.
-
-Revision 1.11  2004/01/24 04:59:16  cheshire
-Fixes so that Posix/Linux, OS9, Windows, and VxWorks targets build again
-
-Revision 1.10  2003/11/14 21:27:09  cheshire
-<rdar://problem/3484766>: Security: Crashing bug in mDNSResponder
-Fix code that should use buffer size MAX_ESCAPED_DOMAIN_NAME (1005) instead of 256-byte buffers.
-
-Revision 1.9  2003/11/14 20:59:09  cheshire
-Clients can't use AssignDomainName macro because mDNSPlatformMemCopy is defined in mDNSPlatformFunctions.h.
-Best solution is just to combine mDNSEmbeddedAPI.h and mDNSPlatformFunctions.h into a single file.
-
-Revision 1.8  2003/10/28 10:08:27  bradley
-Removed legacy port 53 support as it is no longer needed.
-
-Revision 1.7  2003/08/20 05:58:54  bradley
-Removed dependence on modified mDNSCore: define structures/prototypes locally.
-
-Revision 1.6  2003/08/18 23:19:05  cheshire
-<rdar://problem/3382647> mDNSResponder divide by zero in mDNSPlatformRawTime()
-
-Revision 1.5  2003/08/15 00:05:04  bradley
-Updated to use name/InterfaceID from new AuthRecord resrec field. Added output of new record sizes.
-
-Revision 1.4  2003/08/14 02:19:55  cheshire
-<rdar://problem/3375491> Split generic ResourceRecord type into two separate types: AuthRecord and CacheRecord
-
-Revision 1.3  2003/08/12 19:56:27  cheshire
-Update to APSL 2.0
-
-Revision 1.2  2003/08/05 23:58:34  cheshire
-Update code to compile with the new mDNSCoreReceive() function that requires a TTL
-Right now this platform layer just reports 255 instead of returning the real value -- we should fix this
-
-Revision 1.1  2003/08/02 10:06:48  bradley
-mDNS platform plugin for VxWorks.
-
-
 	Notes for non-Apple platforms:
 
 		TARGET_NON_APPLE should be defined to 1 to avoid relying on Apple-only header files, macros, or functions.
@@ -404,7 +302,7 @@ mStatus	mDNSPlatformInit( mDNS * const inMDNS )
 	
 	// Initialize variables.
 
-	memset( &gMDNSPlatformSupport, 0, sizeof( gMDNSPlatformSupport ) );
+	mDNSPlatformMemZero( &gMDNSPlatformSupport, sizeof( gMDNSPlatformSupport ) );
 	inMDNS->p							= &gMDNSPlatformSupport;
 	inMDNS->p->commandPipe				= ERROR;
 	inMDNS->p->task						= ERROR;
@@ -543,7 +441,7 @@ mStatus
 	item = (MDNSInterfaceItem *) inInterfaceID;
 	check( item->sendingSocketRef != kInvalidSocketRef );
 	
-	memset( &addr, 0, sizeof( addr ) );
+	mDNSPlatformMemZero( &addr, sizeof( addr ) );
 	addr.sin_family 		= AF_INET;
 	addr.sin_port 			= inDstPort.NotAnInteger;
 	addr.sin_addr.s_addr 	= inDstIP->ip.v4.NotAnInteger;
@@ -587,7 +485,7 @@ mDNSexport void mDNSPlatformTCPCloseConnection(int sd)
 	(void)sd;			// Unused
 	}
 
-mDNSexport int mDNSPlatformReadTCP(int sd, void *buf, int buflen)
+mDNSexport long mDNSPlatformReadTCP(int sd, void *buf, unsigned long buflen)
 	{
 	(void)sd;			// Unused
 	(void)buf;			// Unused
@@ -595,7 +493,7 @@ mDNSexport int mDNSPlatformReadTCP(int sd, void *buf, int buflen)
 	return(0);
 	}
 
-mDNSexport int mDNSPlatformWriteTCP(int sd, const char *msg, int len)
+mDNSexport long mDNSPlatformWriteTCP(int sd, const char *msg, unsigned long len)
 	{
 	(void)sd;			// Unused
 	(void)msg;			// Unused
@@ -669,7 +567,7 @@ mDNSu32  mDNSPlatformStrLen( const void *inSrc )
 //	mDNSPlatformStrCopy
 //===========================================================================================================================
 
-void	mDNSPlatformStrCopy( const void *inSrc, void *inDst )
+void	mDNSPlatformStrCopy( void *inDst, const void *inSrc )
 {
 	check( inSrc );
 	check( inDst );
@@ -681,7 +579,7 @@ void	mDNSPlatformStrCopy( const void *inSrc, void *inDst )
 //	mDNSPlatformMemCopy
 //===========================================================================================================================
 
-void	mDNSPlatformMemCopy( const void *inSrc, void *inDst, mDNSu32 inSize )
+void	mDNSPlatformMemCopy( void *inDst, const void *inSrc, mDNSu32 inSize )
 {
 	check( inSrc );
 	check( inDst );
@@ -693,7 +591,7 @@ void	mDNSPlatformMemCopy( const void *inSrc, void *inDst, mDNSu32 inSize )
 //	mDNSPlatformMemSame
 //===========================================================================================================================
 
-mDNSBool	mDNSPlatformMemSame( const void *inSrc, const void *inDst, mDNSu32 inSize )
+mDNSBool	mDNSPlatformMemSame( const void *inDst, const void *inSrc, mDNSu32 inSize )
 {
 	check( inSrc );
 	check( inDst );
@@ -1104,7 +1002,7 @@ mDNSlocal mStatus	SetupInterface( mDNS * const inMDNS, const struct ifaddrs *inA
 	item->hostSet.Advertise               = inMDNS->AdvertiseLocalAddresses;
 	item->hostSet.McastTxRx               = mDNStrue;
 
-	err = mDNS_RegisterInterface( inMDNS, &item->hostSet, 0 );
+	err = mDNS_RegisterInterface( inMDNS, &item->hostSet, mDNSfalse );
 	require_noerr( err, exit );
 	item->hostRegistered = mDNStrue;
 	
@@ -1146,7 +1044,7 @@ mDNSlocal mStatus	TearDownInterface( mDNS * const inMDNS, MDNSInterfaceItem *inI
 	if( inItem->hostRegistered )
 	{
 		inItem->hostRegistered = mDNSfalse;
-		mDNS_DeregisterInterface( inMDNS, &inItem->hostSet );
+		mDNS_DeregisterInterface( inMDNS, &inItem->hostSet, mDNSfalse );
 	}
 	
 	// Close the multicast socket.
@@ -1224,17 +1122,17 @@ mDNSlocal mStatus
 		// Join the all-DNS multicast group so we receive Multicast DNS packets.
 		
 		ip.NotAnInteger 			= ipv4->sin_addr.s_addr;
-		mreq.imr_multiaddr.s_addr 	= AllDNSLinkGroupv4.NotAnInteger;
+		mreq.imr_multiaddr.s_addr 	= AllDNSLinkGroup_v4.ip.v4.NotAnInteger;
 		mreq.imr_interface.s_addr 	= ip.NotAnInteger;
 		err = setsockopt( socketRef, IPPROTO_IP, IP_ADD_MEMBERSHIP, (char *) &mreq, sizeof( mreq ) );
 		check_errno( err, errno );
 		
 		// Bind to the multicast DNS address and port 5353.
 		
-		memset( &addr, 0, sizeof( addr ) );
+		mDNSPlatformMemZero( &addr, sizeof( addr ) );
 		addr.sin_family 		= AF_INET;
 		addr.sin_port 			= inPort.NotAnInteger;
-		addr.sin_addr.s_addr 	= AllDNSLinkGroupv4.NotAnInteger;
+		addr.sin_addr.s_addr 	= AllDNSLinkGroup_v4.ip.v4.NotAnInteger;
 		err = bind( socketRef, (struct sockaddr *) &addr, sizeof( addr ) );
 		check_errno( err, errno );
 		
@@ -1246,7 +1144,7 @@ mDNSlocal mStatus
 		// Bind to the interface address and multicast DNS port.
 		
 		ip.NotAnInteger 		= ipv4->sin_addr.s_addr;
-		memset( &addr, 0, sizeof( addr ) );
+		mDNSPlatformMemZero( &addr, sizeof( addr ) );
 		addr.sin_family 		= AF_INET;
 		addr.sin_port 			= MulticastDNSPort.NotAnInteger;
 		addr.sin_addr.s_addr 	= ip.NotAnInteger;
@@ -1441,14 +1339,11 @@ mDNSlocal void	ProcessCommandReconfigure( mDNS *inMDNS )
 	
 	// Inform clients of the change.
 	
-	if( inMDNS->MainCallback )
-	{
-		inMDNS->MainCallback( inMDNS, mStatus_ConfigChanged );
-	}
+	mDNS_ConfigChanged(m);
 	
 	// Force mDNS to update.
 	
-	mDNSCoreMachineSleep( inMDNS, mDNSfalse );
+	mDNSCoreMachineSleep( inMDNS, mDNSfalse ); // What is this for? Mac OS X does not do this
 	
 	// Bump the config ID so the main processing loop detects the configuration change.
 	
@@ -1753,7 +1648,7 @@ mDNSlocal void	TaskProcessPacket( mDNS *inMDNS, MDNSInterfaceItem *inItem, MDNSS
 		srcAddr.ip.v4.NotAnInteger 	= addr.sin_addr.s_addr;
 		srcPort.NotAnInteger		= addr.sin_port;
 		dstAddr.type				= mDNSAddrType_IPv4;
-		dstAddr.ip.v4				= AllDNSLinkGroupv4;
+		dstAddr.ip.v4				= AllDNSLinkGroup_v4.ip.v4;
 		dstPort						= MulticastDNSPort;
 		
 		dlog( kDebugLevelChatty, DEBUG_NAME "packet received\n" );
@@ -1797,7 +1692,7 @@ mDNSlocal void	GenerateUniqueHostName( char *outName, long *ioSeed )
 	
 	// $$$ Non-Apple Platforms: Fill in appropriate name for device.
 	
-	mDNSPlatformStrCopy( kMDNSDefaultName, outName );
+	mDNSPlatformStrCopy( outName, kMDNSDefaultName );
 }
 
 //===========================================================================================================================
@@ -1813,7 +1708,7 @@ mDNSlocal void	GenerateUniqueDNSName( char *outName, long *ioSeed )
 	
 	// $$$ Non-Apple Platforms: Fill in appropriate DNS name for device.
 	
-	mDNSPlatformStrCopy( kMDNSDefaultName, outName );
+	mDNSPlatformStrCopy( outName, kMDNSDefaultName );
 }
 #endif
 
